
function [im_proton, im_pyr, im_lac, im_bic, lambda, subRegion, ...
  ds, magThresh ] = loadDatacase( datacase )

  im_proton=0;  im_pyr=0;  im_lac=0;  im_bic=0;  lambda=0;
  subRegion = [];  % xL yL xR yR

  dataDir = '/Users/nicholasdwork/.DellEMS/Vols/disk2s1/diChromInterpData/';
  if ~exist( dataDir, 'dir' )
    dataDir = '/Users/ndwork/Documents/Data';
  end

  switch datacase
    case 1
      %lambda = 1d-1;
      lambda = 1d-2;

      load( '../data/oneSliceHeart/data.mat' );
      ds = 5;

      im_pyr = shiftImg( im_pyr, [8 2] );
      im_lac = shiftImg( im_lac, [8 2] );
      im_bic = shiftImg( im_bic, [8 2] );

      magThresh = 0.2;

    case 2
      %lambda = 1d4;
      lambda = 1d3;
      load( '../data/manySlicesHeart/data.mat' );
      ds = 5;
      subRegion = [ 30 65 150 165 ];  % xL yL xR yR

      im_pyr = shiftImg( im_pyr, [8 2] );
      im_lac = shiftImg( im_lac, [8 2] );
      im_bic = shiftImg( im_bic, [8 2] );
      
      magThresh = 0.1;

    case 3
      %lambda = 1d-1;
      lambda = 1d-2;

      areas=0;  % stored within mat file
      load( '../data/prostate/pc9154_data.mat' );
      %load( '../data/prostate/pc9154_data_cc.mat' );
      subRegion = [];  % xL yL xR yR

      pngImg = imread( '../data/prostate/pc9154.png' );
      pngImg = double( pngImg(:,:,1) ) / 255.;

      ds = size( pngImg ) ./ [ size(areas,1) size(areas,2) ];
      ds = min( floor( ds ) );

      sAs = size( areas );
      rotAreas = zeros( [ sAs(2), sAs(1), sAs(3:end) ] );
      for k = 1:sAs(5)
        for j = 1:sAs(4)
          for i = 1:sAs(3)
            rotAreas(:,:,i,j,k) = circshift( rot90( areas(:,:,i,j,k), -1 ), [-1 0] );
          end
        end
      end
      im_pyr = abs( squeeze( rotAreas( :, :, 9, 1, 7:end ) ) );
      im_lac = abs( squeeze( rotAreas( :, :, 9, 2, 7:end ) ) );

      pngImg = cropData( pngImg, ds*[ size(rotAreas,1) size(rotAreas,2) ] );
      im_proton = repmat( pngImg, [1 1 size( im_pyr, 3)] );
      clear rotAreas areas;

      sP = size( im_proton );
      resizedPyr = zeros( sP );
      resizedLac = zeros( sP );
      for sliceIndx = 1 : size( im_proton, 3 )
        resizedPyr(:,:,sliceIndx) = imresize( im_pyr(:,:,sliceIndx), [sP(1), sP(2)], 'nearest' );
        resizedLac(:,:,sliceIndx) = imresize( im_lac(:,:,sliceIndx), [sP(1), sP(2)], 'nearest' );
      end
      im_pyr = resizedPyr;  clear resizedPyr;
      im_lac = resizedLac;  clear resizedLac;

      magThresh = 0.15;

    case 4
      %lambda = 1d-1;
      lambda = 1d-2;

      areas=0;  % stored within mat file
      %load( '../data/prostate/pc9154_data.mat' );
      load( '../data/prostate/pc9154_data_cc.mat' );
      subRegion = [];  % xL yL xR yR

      pyrAreas = squeeze( Data_4D_coilcorrect.Pyruvate );
      lacAreas = squeeze( Data_4D_coilcorrect.Lactate );
      areas = zeros( 12, 12, 16, 2, 21 );
      areas(:,:,:,1,:) = pyrAreas;
      areas(:,:,:,2,:) = lacAreas;
      
      pngImg = imread( '../data/prostate/pc9154.png' );
      pngImg = double( pngImg(:,:,1) ) / 255.;
      pngImg = imresize( pngImg, [ 120 120 ], 'bilinear' );

      ds = size( pngImg ) ./ [ size(areas,1) size(areas,2) ];
      ds = min( floor( ds ) );

      sAs = size( areas );
      rotAreas = zeros( [ sAs(2), sAs(1), sAs(3:end) ] );
      for k = 1:sAs(5)
        for j = 1:sAs(4)
          for i = 1:sAs(3)
            rotAreas(:,:,i,j,k) = circshift( rot90( areas(:,:,i,j,k), -1 ), [-1 0] );
          end
        end
      end
      im_pyr = abs( squeeze( rotAreas( :, :, 9, 1, 3:end ) ) );
      im_lac = abs( squeeze( rotAreas( :, :, 9, 2, 3:end ) ) );

      %im_pyr = shiftImg( im_pyr, [1 0] );
      %im_lac = shiftImg( im_lac, [1 0] );

      pngImg = cropData( pngImg, ds*[ size(rotAreas,1) size(rotAreas,2) ] );
      im_proton = repmat( pngImg, [1 1 size( im_pyr, 3)] );
      clear rotAreas areas;

      sP = size( im_proton );
      resizedPyr = zeros( sP );
      resizedLac = zeros( sP );
      for sliceIndx = 1 : size( im_proton, 3 )
        resizedPyr(:,:,sliceIndx) = imresize( im_pyr(:,:,sliceIndx), [sP(1), sP(2)], 'nearest' );
        resizedLac(:,:,sliceIndx) = imresize( im_lac(:,:,sliceIndx), [sP(1), sP(2)], 'nearest' );
      end
      im_pyr = resizedPyr;  clear resizedPyr;
      im_lac = resizedLac;  clear resizedLac;

      magThresh = 0.15;

    case 5
      %lambda = 1d2;  % looks good
      %lambda = 1d3;
      %lambda = 1d12;
      %lambda = 1d-7;
      lambda = 1d-2;
      ds = 5;  % looks good
      load( '../data/pigheart/data.mat' );
      subRegion = [];  % xL yL xR yR

      im_pyr = imresize( im_pyr, size( im_proton ), 'bilinear' );
      im_lac = imresize( im_lac, size( im_proton ), 'bilinear' );
      im_bic = imresize( im_bic, size( im_proton ), 'bilinear' );
      
      magThresh = 0.2;

    case 6
      ds = 7;      
      im_proton = rgb2gray( double( imread( '../data/bottlePhantom/proton.png' ) ) / 255. );
      im_pyr = rgb2gray( double( imread( '../data/bottlePhantom/metabolite.png' ) ) / 255. );

    case 7
      ds = 7;
      t1Dicom = [ dataDir, '/Phantom_Experiment/Phantom_Experiment/Unnamed - 985/t1w_axial_overlay_8/IM-0008-0001.dcm' ];
      metDir = [ dataDir, 'Phantom_Experiment/Phantom_Experiment/Unnamed - 985/MNSRP;TS4_MET2_SL1;0;spsp;13C_SPSP_32132870_7' ];

      im_proton = double( dicomread( t1Dicom ) );
      sImg = size( im_proton );

      metFiles = dir( [ metDir, '/*.DCM' ] );
      nMetFiles = numel( metFiles );
      im_mets = zeros( [ sImg nMetFiles ] );
      for fileIndx = 1 : nMetFiles
        dicomFilename = [ metDir, '/', metFiles( fileIndx ).name ];
        metImg = double( dicomread( dicomFilename ) );
        im_mets(:,:,fileIndx) = imresize( metImg, sImg );
      end

      im_pyr = mean( im_mets(:,:,1:4), 3 );    % actually a phantom metabolite
      im_lac = mean( im_mets(:,:,5:end), 3 );  % actually a phantom metabolite

      im_pyr = circshift( im_pyr, [ 3 -3 ] );
      im_lac = circshift( im_lac, [ 9 -1 ] );
  end

end
