
function run_diChromInterp( datacases, varargin )
  showImages = false;
  if nargin < 1, close all; rng(1); clear; end
  addpath( './dworkLib' );

  blurFraction = 0.5;
  gamma = 4;
  algs = { 'diChromInterp+', 'diChromInterp', 'deNoiseAndInterp' };
  lambdas = [ 2, 5 1d-2, 1d-1, 1, 1d1, 1d2, 1d3, 1d4, 1d5 ];
  outDir = 'output';

  if nargin < 1
    datacases = 1:7;
    showImages = false;
  end


  nDatacases = numel( datacases );
  for datacaseIndx = 1 : nDatacases
    datacase = datacases( datacaseIndx );
    if ~exist( 'showImages', 'var' ) || showImages == false, close all; end

    for algIndx = 1 : numel( algs )
      alg = algs{ algIndx };

      if regexp( alg, '^diChromInterp' )
        nOptIter = 100;
      else
        nOptIter = 300;
      end

      nLambdas = numel( lambdas );
      parfor lambdaIndx = 1 : nLambdas
        lambda = lambdas( lambdaIndx );

        im_proton=0;  im_pyr=0;  im_lac=0;  im_bic=0;   %#ok<NASGU>
        subRegion = [];
        [im_proton, im_pyr, im_lac, im_bic, ~, ~, ds] = loadDatacase( datacase );

        fullOutDir = [ './', outDir, '/', alg, '/datacase_', indx2str(datacase,max(datacases)), ...
          '/lambda_', num2str( lambda )];
        if ~exist( fullOutDir, 'dir' ), mkdir( fullOutDir ); end

        maxProton = max( im_proton(:) );
        im_proton = im_proton / maxProton;
        maxPyr = max( im_pyr(:) );
        im_pyr = im_pyr / maxPyr;

        if numel( im_lac ) > 1
          maxLac = max( im_lac(:) );
          im_lac = im_lac / maxLac;
        end

        if numel( im_bic ) > 1
          maxBic = max( im_bic(:) );
          im_bic = im_bic / maxBic;
        end

        nSlices = size( im_pyr, 3 );
        origPyrs = cell( 1, 1, nSlices );
        interpPyrs = cell( 1, 1, nSlices );
        origLacs = cell( 1, 1, nSlices );
        interpLacs = cell( 1, 1, nSlices );
        origBics = cell( 1, 1, nSlices );
        interpBics = cell( 1, 1, nSlices );
        resizedProtons = cell( 1, 1, nSlices );

        %parfor( sliceIndx = 1 : nSlices )
        for sliceIndx = 1 : nSlices
          disp( [ 'Working on datacase / lambdaIndx / sliceIndx:  ', indx2str( datacase, max(datacases) ), ...
            ' / ', indx2str( lambdaIndx, nLambdas ), ' / ', indx2str( sliceIndx, nSlices ) ] );
          thisProton = smoothImg( im_proton(:,:,sliceIndx), 5 );
          if numel( subRegion ) > 0
            xL = subRegion(1);  xR = subRegion(3);
            yL = subRegion(2);  yR = subRegion(4);
          else
            sProton = size( thisProton );
            xL = 1;  xR = sProton(2);
            yL = 1;  yR = sProton(1);
          end
          thisProton2Save = thisProton( yL : yR, xL : xR );
          imwrite( thisProton2Save, [ fullOutDir, '/origProton_', num2str(sliceIndx,'%3.3i'), '.jpg'] );

          thisPyr = downsize2( im_pyr(:,:,sliceIndx), round( size(im_pyr(:,:,sliceIndx))/ds ) );
          thisPyrResized = imresize( thisPyr, size(thisProton), 'nearest' );
          origPyrs{ sliceIndx } = thisPyrResized( yL : yR, xL : xR );
          thisPyr2Save = thisPyrResized( yL : yR, xL : xR );
          imwrite( thisPyr2Save, [ fullOutDir, '/origPyr_', num2str(sliceIndx,'%3.3i'), '.jpg'] );

          thisInterpPyr = interpThisImage( alg, thisProton, thisPyr, blurFraction*ds, ...
            'lambda', lambda, 'N', nOptIter );
          thisInterpPyr2Save = thisInterpPyr( yL : yR, xL : xR );
          imwrite( thisInterpPyr2Save, [ fullOutDir, '/interpPyr_', ...
            num2str(sliceIndx,'%3.3i'), '.jpg'] );
          interpPyrs{ sliceIndx } = thisInterpPyr( yL : yR, xL : xR );

          if numel( im_lac ) > 1
            thisLac = downsize2( im_lac(:,:,sliceIndx), round( size(im_lac(:,:,sliceIndx))/ds ) );
            thisLacResized = imresize( thisLac, size( thisProton ), 'nearest' );
            origLacs{ sliceIndx } = thisLacResized( yL : yR, xL : xR );
            thisLac2Save = thisLacResized( yL : yR, xL : xR );
            imwrite( thisLac2Save, [ fullOutDir, '/origLac_', num2str(sliceIndx,'%3.3i'), '.jpg'] );

            thisInterpLac = interpThisImage( alg, thisProton, thisLac, blurFraction*ds, ...
              'lambda', lambda, 'N', nOptIter );
            thisInterpLac2Save = thisInterpLac( yL : yR, xL : xR );
            imwrite( thisInterpLac2Save, [ fullOutDir, '/interpLac_', ...
              num2str(sliceIndx,'%3.3i'), '.jpg'] );
            interpLacs{ sliceIndx } = thisInterpLac( yL : yR, xL : xR );

          end

          if numel( im_bic ) > 1
            thisBic = downsize2( im_bic(:,:,sliceIndx), round( size(im_bic(:,:,sliceIndx))/ds ) );
            thisBicResized = imresize( thisBic, size(thisProton), 'nearest' );
            origBics{ sliceIndx } = thisBicResized( yL : yR, xL : xR );
            thisBic2Save = thisBicResized( yL : yR, xL : xR );
            imwrite( thisBic2Save, [ fullOutDir, '/origBic_', num2str(sliceIndx,'%3.3i'), '.jpg'] );

            thisInterpBic = interpThisImage( alg, thisProton, thisBic, 0.25*ds, ...
              'lambda', lambda, 'N', nOptIter );
            thisInterpBic2Save = thisInterpBic( yL : yR, xL : xR );
            imwrite( thisInterpBic2Save, [ fullOutDir, '/interpBic_', ...
              num2str(sliceIndx,'%3.3i'), '.jpg'] );
            interpBics{ sliceIndx } = thisInterpBic( yL : yR, xL : xR );
          end

          thisResizedProton = thisProton( ...
            1 : size(thisInterpPyr,1), 1 : size(thisInterpPyr,2) );
          resizedProtons{ sliceIndx } = thisResizedProton( yL : yR, xL : xR );
          thisResizedProton2Save = thisResizedProton( yL : yR, xL : xR );
          imwrite( thisResizedProton2Save, [ fullOutDir, '/origResizedProton_', ...
            num2str(sliceIndx,'%3.3i'), '.jpg'] );

          if showImages == false, close all; end
        end

        interpPyrs = cell2mat( interpPyrs );
        origPyrs = cell2mat( origPyrs );
        if numel( im_lac ) > 1
          origLacs = cell2mat( origLacs );
          interpLacs = cell2mat( interpLacs );
        end
        if numel( im_bic ) > 1
          origBics = cell2mat( origBics );
          interpBics = cell2mat( interpBics );
        end
        resizedProtons = cell2mat( resizedProtons );

        nImgsPerRow = 5;

        f = figure;
        showImageCube( resizedProtons/max(resizedProtons(:))*255, 3, ...
          'nImgsPerRow', nImgsPerRow, 'border', 3, 'range', 'nice' );
        pFrame=getframe(gcf);  proton4Fusion = double( pFrame.cdata ) / 255.;
        if showImages == false, close(f); end
        proton4Fusion = mean( proton4Fusion, 3 );
        imwrite( proton4Fusion, [ fullOutDir, '/protons.jpg' ] );

        f = figure;
        showImageCube( origPyrs, 3, 'nImgsPerRow', nImgsPerRow, 'border', 3 );
        titlenice( 'Original Pyruvate Images' );
        pFrame=getframe(gcf);  origPyrs = double( pFrame.cdata ) / 255.;
        if showImages ~= true, close(f); end
        origPyrs = mean( origPyrs, 3 );
        imwrite( origPyrs, [ fullOutDir, '/pyruvatesOrig.jpg' ] );

        f = figure;
        showImageCube( interpPyrs, 3, 'nImgsPerRow', nImgsPerRow, 'border', 3 );
        titlenice( 'Pyruvate Images' );
        pFrame=getframe(gcf);  pyruvates = double( pFrame.cdata ) / 255.;
        if showImages ~= true, close(f); end
        pyruvates = mean( pyruvates, 3 );
        imwrite( pyruvates, [ fullOutDir, '/pyruvatesSR.jpg' ] );

        f = figure;
        showImageCube( interpPyrs, 3, 'nImgsPerRow', nImgsPerRow, 'border', 3, ...
          'range', [0 1] );
        titlenice( 'Pyruvate Images' );  colormap( gca, 'hot' );
        pFrame=getframe(gcf);  pHot = double( pFrame.cdata ) / 255.;
        if showImages == false, close(f); end
        imwrite( pHot, [ fullOutDir, '/pyruvatesSR_hot.jpg' ] );

        pFused = alphaBlend( pHot, proton4Fusion, 0.3 );
        if showImages == true
          figure; imshowscale( pFused );  titlenice( 'Pyruvate Fused - Alpha Blend' );
        end
        imwrite( pFused, [ fullOutDir, '/fusedPyrAlpha.jpg' ] );

        pFused = clsFusion( pHot, proton4Fusion, gamma );
        if showImages == true
          figure; imshowscale( pFused );  titlenice( 'Pyruvate Fused - CLS' );
        end
        imwrite( pFused, [ fullOutDir, '/fusedPyrCLS.jpg' ] );

        if numel( im_lac ) > 1

          f = figure;
          showImageCube( origLacs, 3, 'nImgsPerRow', nImgsPerRow, 'border', 3 );
          titlenice( 'Original Lactate Images' );
          pFrame=getframe(gcf);  lactates = double( pFrame.cdata ) / 255.;
          if showImages ~= true, close(f); end
          imwrite( lactates, [ fullOutDir, '/lactatesOrig.jpg' ] );

          f = figure;
          showImageCube( origLacs, 3, 'nImgsPerRow', nImgsPerRow, 'border', 3 );
          titlenice( 'Lactate Images' );  colormap( gca, 'hot' );
          pFrame=getframe(gcf);  lacHot = double( pFrame.cdata ) / 255.;
          if showImages ~= true, close(f); end
          imwrite( lacHot, [ fullOutDir, '/lactates_hot.jpg' ] );

          f = figure;
          showImageCube( interpLacs, 3, 'nImgsPerRow', nImgsPerRow, 'border', 3 );
          titlenice( 'Lactate Images' );
          pFrame=getframe(gcf);  lacHot = double( pFrame.cdata ) / 255.;
          if showImages ~= true, close(f); end
          imwrite( lacHot, [ fullOutDir, '/lactatesSR.jpg' ] );

          f = figure;
          showImageCube( interpLacs, 3, 'nImgsPerRow', nImgsPerRow, 'border', 3, ...
            'range', [0 1] );
          titlenice( 'Lactate Images' );  colormap( gca, 'hot' );
          pFrame=getframe(gcf);  lacHot = double( pFrame.cdata ) / 255.;
          if showImages ~= true, close(f); end
          imwrite( lacHot, [ fullOutDir, '/lactatesSR_hot.jpg' ] );

          lacFused = alphaBlend( lacHot, proton4Fusion, 0.3 );
          if showImages == true
            figure; imshowscale( lacFused );  titlenice( 'Lactate Fused - Alpha' );
          end
          imwrite( lacFused, [ fullOutDir, '/fusedLacAlpha.jpg' ] );

          lacFused = clsFusion( lacHot, proton4Fusion, gamma );
          if showImages == true
            figure; imshowscale( lacFused );  titlenice( 'Lactate Fused - CLS' );
          end
          imwrite( lacFused, [ fullOutDir, '/fusedLacCLS.jpg' ] );
        end

        if numel( im_bic ) > 1
          f = figure;
          showImageCube( origBics, 3, 'nImgsPerRow', nImgsPerRow, 'border', 3 );
          titlenice( 'Original Bicarbonate Images' );
          pFrame=getframe(gcf);  bicarbsOrig = mean( double( pFrame.cdata ) / 255., 3 );
          if showImages ~= true, close(f); end
          imwrite( bicarbsOrig, [ fullOutDir, '/bicarbsOrig.jpg' ] );

          f = figure;
          showImageCube( interpBics, 3, 'nImgsPerRow', nImgsPerRow, 'border', 3 );
          titlenice( 'Bicarbonate Images SuperResolved' );
          pFrame=getframe(gcf);  bicarbsSR = mean( double( pFrame.cdata ) / 255., 3 );
          if showImages ~= true, close(f); end
          imwrite( bicarbsSR, [ fullOutDir, '/bicarbsSR.jpg' ] );

          f = figure;
          showImageCube( interpBics, 3, 'nImgsPerRow', nImgsPerRow, 'border', 3, ...
            'range', [0 1] );
          titlenice( 'Bicarbonate Images' );  colormap( gca, 'hot' );
          bFrame=getframe(gcf);  bColor = double( bFrame.cdata ) / 255.;
          if showImages == false, close(f); end
          imwrite( bColor, [ fullOutDir, '/bicarbsSR_hot.jpg' ] );

          bicFused = alphaBlend( bColor, proton4Fusion, 0.3 );
          if showImages == true
            figure; imshowscale( bicFused );  titlenice( 'Bicarbonate Fused - Alpha' );
          end
          imwrite( bicFused, [ fullOutDir, '/fusedBicAlpha.jpg' ] );

          bicFused = clsFusion( bColor, proton4Fusion, gamma );
          if showImages == true
            figure; imshowscale( bicFused );  titlenice( 'Bicarbonate Fused - CLS' );
          end
          imwrite( bicFused, [ fullOutDir, '/fusedBicCLS.jpg' ] );
        end
      end

    end
  end

end

