
function run_phantom()
  close all; rng(1); clear;
  addpath( './dworkLib' );

  ds = 4;
  blurFraction = 0.5;
  lambda = 1d5;
  showScale = 3;

  [ ph, lowResMet, met ] = makePhantom( ds );

  nnMet = imresize( lowResMet, size( ph ), 'nearest' );  % Nearest Neighbor
  upscaledMet = imresize( lowResMet, size( ph ), 'bilinear' );

  interped = diChromInterp( ph, upscaledMet, blurFraction * ds, 'lambda', lambda );

  figure; imshowscale( ph, showScale );  titlenice( 'Anatomical Phantom' );
  figure; imshowscale( met, showScale );  titlenice( 'High Res Metabolic Phantom' );
  figure; imshowscale( nnMet, showScale );  titlenice( 'Nearest Neighbor Metabolic Phantom' );
  figure; imshowscale( upscaledMet, showScale, 'range', met );  titlenice( 'Linearly Interpolated Metabolic Phantom' );
  figure; imshowscale( met + ph, showScale );  titlenice( 'Sum of phantoms' );
  figure; imshowscale( interped, showScale, 'range', met );  titlenice( 'Dichromatic Interpolated' );

  linRelErr = relError( upscaledMet, met );
  diChromErr = relError( interped, met );

  disp([ 'Linear interpolation relative error: ', num2str( linRelErr ) ] );
  disp([ 'Di-chrom interpolation relative error: ', num2str( diChromErr ) ] );
end


function out = relError( estimate, true )

  out = norm( estimate(:) - true(:) ) / norm( true(:) );

end
